@@ -1,76 +1,10 @@
 /*
- * JBoss, Home of Professional Open Source.
- * Copyright 2016, Red Hat, Inc., and individual contributors
- * as indicated by the @author tags. See the copyright.txt file in the
- * distribution for a full listing of individual contributors.
- *
- * This is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1 of
- * the License, or (at your option) any later version.
- *
- * This software is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this software; if not, write to the Free
- * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
- * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ * Copyright The WildFly Authors
+ * SPDX-License-Identifier: Apache-2.0
  */
 
 package org.jboss.as.ejb3.remote;
 
-import org.jboss.as.ee.component.Component;
-import org.jboss.as.ee.component.ComponentIsStoppedException;
-import org.jboss.as.ee.component.ComponentView;
-import org.jboss.as.ee.component.interceptors.InvocationType;
-import org.jboss.as.ejb3.component.EJBComponentUnavailableException;
-import org.jboss.as.ejb3.component.interceptors.CancellationFlag;
-import org.jboss.as.ejb3.component.session.SessionBeanComponent;
-import org.jboss.as.ejb3.component.stateful.StatefulSessionComponent;
-import org.jboss.as.ejb3.component.stateless.StatelessSessionComponent;
-import org.jboss.as.ejb3.deployment.DeploymentModuleIdentifier;
-import org.jboss.as.ejb3.deployment.DeploymentRepository;
-import org.jboss.as.ejb3.deployment.DeploymentRepositoryListener;
-import org.jboss.as.ejb3.deployment.EjbDeploymentInformation;
-import org.jboss.as.ejb3.deployment.ModuleDeployment;
-import org.jboss.as.ejb3.logging.EjbLogger;
-import org.jboss.as.network.ClientMapping;
-import org.jboss.as.network.ProtocolSocketBinding;
-import org.jboss.as.security.remoting.RemoteConnection;
-import org.jboss.ejb.client.Affinity;
-import org.jboss.ejb.client.ClusterAffinity;
-import org.jboss.ejb.client.EJBClientInvocationContext;
-import org.jboss.ejb.client.EJBIdentifier;
-import org.jboss.ejb.client.EJBLocator;
-import org.jboss.ejb.client.EJBMethodLocator;
-import org.jboss.ejb.client.EJBModuleIdentifier;
-import org.jboss.ejb.client.NodeAffinity;
-import org.jboss.ejb.client.SessionID;
-import org.jboss.ejb.client.StatefulEJBLocator;
-import org.jboss.ejb.server.Association;
-import org.jboss.ejb.server.CancelHandle;
-import org.jboss.ejb.server.ClusterTopologyListener;
-import org.jboss.ejb.server.InvocationRequest;
-import org.jboss.ejb.server.ListenerHandle;
-import org.jboss.ejb.server.ModuleAvailabilityListener;
-import org.jboss.ejb.server.Request;
-import org.jboss.ejb.server.SessionOpenRequest;
-import org.jboss.invocation.InterceptorContext;
-import org.jboss.remoting3.Connection;
-import org.wildfly.clustering.Registration;
-import org.wildfly.clustering.group.Group;
-import org.wildfly.clustering.registry.Registry;
-import org.wildfly.clustering.registry.RegistryListener;
-import org.wildfly.common.annotation.NotNull;
-import org.wildfly.security.auth.server.SecurityIdentity;
-import org.wildfly.security.manager.WildFlySecurityManager;
-
-import javax.ejb.EJBException;
-import javax.net.ssl.SSLSession;
-
 import java.io.IOException;
 import java.lang.reflect.Method;
 import java.net.InetAddress;
@@ -89,9 +23,55 @@ import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Executor;
 import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicBoolean;
+import jakarta.ejb.EJBException;
+
+import org.jboss.as.ee.component.Component;
+import org.jboss.as.ee.component.ComponentIsStoppedException;
+import org.jboss.as.ee.component.ComponentView;
+import org.jboss.as.ee.component.interceptors.InvocationType;
+import org.jboss.as.ejb3.component.EJBComponentUnavailableException;
+import org.jboss.as.ejb3.component.interceptors.CancellationFlag;
+import org.jboss.as.ejb3.component.session.SessionBeanComponent;
+import org.jboss.as.ejb3.component.stateful.StatefulSessionComponent;
+import org.jboss.as.ejb3.component.stateless.StatelessSessionComponent;
+import org.jboss.as.ejb3.deployment.DeploymentModuleIdentifier;
+import org.jboss.as.ejb3.deployment.DeploymentRepository;
+import org.jboss.as.ejb3.deployment.DeploymentRepositoryListener;
+import org.jboss.as.ejb3.deployment.EjbDeploymentInformation;
+import org.jboss.as.ejb3.deployment.ModuleDeployment;
+import org.jboss.as.ejb3.logging.EjbLogger;
+import org.jboss.as.network.ClientMapping;
+import org.jboss.as.network.ProtocolSocketBinding;
+import org.jboss.ejb.client.Affinity;
+import org.jboss.ejb.client.ClusterAffinity;
+import org.jboss.ejb.client.EJBClientInvocationContext;
+import org.jboss.ejb.client.EJBIdentifier;
+import org.jboss.ejb.client.EJBLocator;
+import org.jboss.ejb.client.EJBMethodLocator;
+import org.jboss.ejb.client.EJBModuleIdentifier;
+import org.jboss.ejb.client.NodeAffinity;
+import org.jboss.ejb.client.SessionID;
+import org.jboss.ejb.client.StatefulEJBLocator;
+import org.jboss.ejb.server.Association;
+import org.jboss.ejb.server.CancelHandle;
+import org.jboss.ejb.server.ClusterTopologyListener;
+import org.jboss.ejb.server.InvocationRequest;
+import org.jboss.ejb.server.ListenerHandle;
+import org.jboss.ejb.server.ModuleAvailabilityListener;
+import org.jboss.ejb.server.Request;
+import org.jboss.ejb.server.SessionOpenRequest;
+import org.jboss.invocation.InterceptorContext;
+import org.wildfly.clustering.Registration;
+import org.wildfly.clustering.group.Group;
+import org.wildfly.clustering.registry.Registry;
+import org.wildfly.clustering.registry.RegistryListener;
+import org.wildfly.common.annotation.NotNull;
+import org.wildfly.security.auth.server.SecurityIdentity;
+import org.wildfly.security.manager.WildFlySecurityManager;
 
 /**
  * @author <a href="mailto:tadamski@redhat.com">Tomasz Adamski</a>
+ * @author <a href="mailto:jbaesner@redhat.com">Joerg Baesner</a>
  */
 final class AssociationImpl implements Association, AutoCloseable {
 
@@ -228,24 +208,6 @@ final class AssociationImpl implements Association, AutoCloseable {
             // invoke the method
             final Object result;
 
-            // the Remoting connection that is set here is only used for legacy purposes
-            Connection remotingConnection = invocationRequest.getProviderInterface(Connection.class);
-            if(remotingConnection != null) {
-                SecurityActions.remotingContextSetConnection(remotingConnection);
-            } else if (invocationRequest.getSecurityIdentity() != null) {
-                SecurityActions.remotingContextSetConnection(new RemoteConnection() {
-                    @Override
-                    public SSLSession getSslSession() {
-                        return null;
-                    }
-
-                    @Override
-                    public SecurityIdentity getSecurityIdentity() {
-                        return invocationRequest.getSecurityIdentity();
-                    }
-                });
-            }
-
             try {
                 final Map<String, Object> contextDataHolder = new HashMap<>();
                 result = invokeMethod(componentView, invokedMethod, invocationRequest, requestContent, cancellationFlag, actualLocator, contextDataHolder);
@@ -282,8 +244,6 @@ final class AssociationImpl implements Association, AutoCloseable {
                 }
                 invocationRequest.writeException(exceptionToWrite);
                 return;
-            } finally {
-                SecurityActions.remotingContextClear();
             }
             // invocation was successful
             if (! oneWay) try {
@@ -417,7 +377,15 @@ final class AssociationImpl implements Association, AutoCloseable {
 
     @Override
     public ListenerHandle registerClusterTopologyListener(@NotNull final ClusterTopologyListener listener) {
-        ClusterTopologyRegistrar registrar = this.findClusterTopologyRegistrar(listener.getConnection().getLocalAddress());
+        SocketAddress localAddress = listener.getConnection().getLocalAddress();
+        ClusterTopologyRegistrar registrar = this.findClusterTopologyRegistrar(localAddress);
+        // if the registrar is null, this means that the connector has not been registered on the <remote connectors=/> attribute
+        // and this represents an invalid server configuration (see WFLY-14567)
+        if (registrar == null) {
+            int port = (localAddress instanceof InetSocketAddress) ? ((InetSocketAddress)localAddress).getPort() : 0 ;
+            String address = (localAddress instanceof InetSocketAddress) ? ((InetSocketAddress)localAddress).getAddress().toString() : "0.0.0.0" ;
+            EjbLogger.EJB3_INVOCATION_LOGGER.connectorNotConfiguredForEJBClientInvocations(address, port);
+        }
         return (registrar != null) ? registrar.registerClusterTopologyListener(listener) : NOOP_LISTENER_HANDLE;
     }
 
@@ -494,7 +462,7 @@ final class AssociationImpl implements Association, AutoCloseable {
         return moduleDeployment.getEjbs().get(beanName);
     }
 
-    private class ClusterTopologyRegistrar implements RegistryListener<String, List<ClientMapping>> {
+    private static final class ClusterTopologyRegistrar implements RegistryListener<String, List<ClientMapping>> {
         private final Set<ClusterTopologyListener> clusterTopologyListeners = ConcurrentHashMap.newKeySet();
         private final Registry<String, List<ClientMapping>> clientMappingRegistry;
         private final Registration listenerRegistration;
@@ -658,6 +626,9 @@ final class AssociationImpl implements Association, AutoCloseable {
         for(String key : returnKeys) {
             if(interceptorContext.getContextData().containsKey(key)) {
                 contextDataHolder.put(key, interceptorContext.getContextData().get(key));
+            } else {
+                // need to remove the attachment, as the ContextData value for this key got removed
+                content.getAttachments().remove(key);
             }
         }
     }
@@ -690,7 +661,7 @@ final class AssociationImpl implements Association, AutoCloseable {
     }
 
     private static Affinity getStrongAffinity(final StatefulSessionComponent statefulSessionComponent) {
-        return statefulSessionComponent.getCache().getStrictAffinity();
+        return statefulSessionComponent.getCache().getStrongAffinity();
     }
 
     private static Affinity getWeakAffinity(final StatefulSessionComponent statefulSessionComponent, final StatefulEJBLocator<?> statefulEJBLocator) {
